Module builder

A builder API for creating a Dictionary from scratch.

Structs

AbbreviationData
CategoryData
ComponentData
DatatypeData
DictionaryBuilder
A public API for building a Dictionary from scratch.
FieldData
A field is identified by a unique tag number and a name. Each field in a message is associated with a value.
FieldEnumData
LayoutItemData
MessageData

Enums

LayoutItemKindData