Struct DictionaryBuilder

pub struct DictionaryBuilder { /* private fields */ }
A public API for building a Dictionary from scratch.

It’s better to normally rely on safe wrappers around this builder, such as Dictionary::from_quickfix_spec. This builder is nonetheless useful if you’re building a Dictionary from some custom format.

Warning

DictionaryBuilder tries its best to enforce data consistency and correctness rules for the dictionaries it builds, but you shouldn’t rely on it to catch all possible errors. Make sure the dictionaries you build are correct and consistent.

Implementations

Source

impl DictionaryBuilder

Builder utilities

pub fn new(dict: Dictionary) -> Self

pub fn dict(&self) -> &Dictionary

Returns the underlying Dictionary currently being built.

pub fn build(self) -> Dictionary

Returns the finished Dictionary.

pub fn add_field(&mut self, field: FieldData)

pub fn add_message(&mut self, message: MessageData)

pub fn add_component(&mut self, component: ComponentData)

pub fn add_datatype(&mut self, datatype: DatatypeData)

pub fn add_category(&mut self, category: CategoryData)