Struct MessageData

pub struct MessageData {
    pub component_id: u32,
    pub msg_type: String,
    pub name: String,
    pub category_name: String,
    pub section_id: String,
    pub layout_items: Vec<LayoutItemData>,
    pub abbr_name: Option<String>,
    pub required: bool,
    pub description: String,
    pub elaboration: Option<String>,
}

Fields

component_id: u32

The unique integer identifier of this message type.

msg_type: String

Primary key. The unique character identifier of this message type; used literally in FIX messages.

name: String

The name of this message type.

category_name: String

Identifier of the category to which this message belongs.

section_id: String

Identifier of the section to which this message belongs.

layout_items: Vec<LayoutItemData>abbr_name: Option<String>

The abbreviated name of this message, when used in an XML context.

required: bool

A boolean used to indicate if the message is to be generated as part of FIXML.

description: Stringelaboration: Option<String>