A builder API for creating a Dictionary from scratch.
Structs
- Abbreviation
Data - Category
Data - Component
Data - Datatype
Data - Dictionary
Builder - A public API for building a
Dictionaryfrom scratch. - Field
Data - A field is identified by a unique tag number and a name. Each field in a message is associated with a value.
- Field
Enum Data - Layout
Item Data - Message
Data