pub struct FieldData {
pub name: String,
pub tag: u32,
pub data_type_name: String,
pub associated_data_tag: Option<usize>,
pub value_restrictions: Option<SmallVec<[FieldEnumData; 16]>>,
pub abbr_name: Option<String>,
pub base_category_id: Option<usize>,
pub base_category_abbr_name: Option<String>,
pub required: bool,
pub description: Option<String>,
}Expand description
A field is identified by a unique tag number and a name. Each field in a message is associated with a value.
Fields
name: StringA human readable string representing the name of the field.
tag: u32Primary key. A positive integer representing the unique identifier for this field type.
data_type_name: StringThe datatype of the field.
associated_data_tag: Option<usize>The associated data field. If given, this field represents the length of the referenced data field
value_restrictions: Option<SmallVec<[FieldEnumData; 16]>>abbr_name: Option<String>Abbreviated form of the Name, typically to specify the element name when the field is used in an XML message. Can be overridden by BaseCategory / BaseCategoryAbbrName.
base_category_id: Option<usize>Specifies the base message category when field is used in an XML message.
base_category_abbr_name: Option<String>If BaseCategory is specified, this is the XML element identifier to use for this field, overriding AbbrName.
required: boolIndicates whether the field is required in an XML message.
description: Option<String>