pub struct MessageData {
pub component_id: u32,
pub msg_type: String,
pub name: String,
pub category_name: String,
pub section_id: String,
pub layout_items: Vec<LayoutItemData>,
pub abbr_name: Option<String>,
pub required: bool,
pub description: String,
pub elaboration: Option<String>,
}Fields
component_id: u32The unique integer identifier of this message type.
msg_type: StringPrimary key. The unique character identifier of this message type; used literally in FIX messages.
name: StringThe name of this message type.
category_name: StringIdentifier of the category to which this message belongs.
section_id: StringIdentifier of the section to which this message belongs.
layout_items: Vec<LayoutItemData>abbr_name: Option<String>The abbreviated name of this message, when used in an XML context.
required: boolA boolean used to indicate if the message is to be generated as part of FIXML.
description: Stringelaboration: Option<String>Trait Implementations
Sourceimpl Clone for MessageData
impl Clone for MessageData
Sourcefn clone(&self) -> MessageData
fn clone(&self) -> MessageData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MessageData
impl RefUnwindSafe for MessageData
impl Send for MessageData
impl Sync for MessageData
impl Unpin for MessageData
impl UnwindSafe for MessageData